@@ -57,7 +57,7 @@ Target::~Target()
 
 void Target::freeResources()
 {
-    qDebug () << " free resources for " << this->id;
+    //qDebug () << " free resources for " << this->id;
     if(picture) delete picture;
     if(pictureBack) delete pictureBack;
     picture = NULL;
@@ -74,7 +74,7 @@ void Target::freeResources()
 
 void Target::freeFieldList()
 {
-    qDebug () << " free list for " << this->id;
+    //qDebug () << " free list for " << this->id;
 	TargetField * field;
 	foreach(field,this->fields) {
 		delete field;
@@ -1508,7 +1508,7 @@ QList<Target*> DatabaseManager::getTargets(const QString * filter)
 	while (query.next()) {
 		Target * target = new Target();
 		target->id = query.value(0).toInt();
-		qDebug () << "found target " << target->id;
+		//qDebug () << "found target " << target->id;
 		target->type = query.value(2).toString();
 		//qDebug () << "found target type" << query.value(2);
 		if (query.value(3).isNull())
@@ -1545,7 +1545,7 @@ QList<Target*> DatabaseManager::getFullTargets()
 	while (query.next()) {
 		Target * target = new Target();
 		target->id = query.value(0).toInt();
-		qDebug () << "found target " << target->id;
+		//qDebug () << "found target " << target->id;
 		target->type = query.value(2).toString();
 		//qDebug () << "found target " << query.value(2);
 		if (query.value(3).isNull ())
@@ -1607,7 +1607,7 @@ bool DatabaseManager::_deleteTarget(int idTarget)
 		if (ret) {
 			ret = query.prepare("delete from targets where id=:code");
 			if (ret) {
-				qDebug () << "DELETE " << idTarget;
+				//qDebug () << "DELETE " << idTarget;
                 query.bindValue(":code", idTarget);
 				ret = query.exec();
 			}
@@ -1883,7 +1883,7 @@ bool DatabaseManager::insertTargetField(TargetField* field)
 
 void DatabaseManager::getFields(Target * target)
 {
-	qDebug () << "get fields " << target->name << " " << currentVersion;
+	//qDebug () << "get fields " << target->name << " " << currentVersion;
 
 	if (target->listLoaded) return;
 
