@@ -297,7 +297,9 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	if (edit || this->target->getPicture() != NULL) {
 		imageLabel = new QLabelImage(this);
-
+#ifndef OPEN_SOURCE_VERSION
+	QObject::connect(imageLabel, SIGNAL(clicked(QImage *)), this, SLOT(seePicture(QImage *)));
+#endif
 		if (edit) {
 			imageLabel->setMaximumSize(BIG_WIDTH, BIG_HEIGH);
 			imageLabel->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
@@ -338,7 +340,9 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	if (edit || this->target->getPictureBack() != NULL) {
 		imageBackLabel = new QLabelImage(this);
-
+#ifndef OPEN_SOURCE_VERSION
+	QObject::connect(imageBackLabel, SIGNAL(clicked (QImage *)), this, SLOT(seePicture(QImage *)));
+#endif
 		if (edit) {
 			imageBackLabel->setMaximumSize(BIG_WIDTH, BIG_HEIGH);
 			imageBackLabel->setMinimumSize(BIG_WIDTH, BIG_HEIGH);
@@ -707,7 +711,10 @@ void DetailWindow::showFields (bool firstTime) {
 						}
 						else
 						if (field->type == TYPE_IMAGE) {
-							QLabelImage * imageLabel = new QLabelImage(); //"", false, true, edit, this);
+							QLabelImage * imageLabel = new QLabelImage(this); //"", false, true, edit, this);
+#ifndef OPEN_SOURCE_VERSION
+	QObject::connect(imageLabel, SIGNAL(clicked (QImage *)), this, SLOT(seePicture(QImage *)));
+#endif
 							imageLabel->setUserData(0, new ButtonInfo (field));
 
 							componentLayout->addWidget(imageLabel, pos, 1, 1, 1);
@@ -734,6 +741,22 @@ void DetailWindow::showFields (bool firstTime) {
 	}
 }
 
+void DetailWindow::seePicture(QImage * image) {
+	if (viewerWindow.isNull() && image != NULL) {
+		viewerWindow = new ImageViewer(new QImage (*image), this);
+		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
+        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
+        viewerWindow->show();
+	}
+}
+
+void DetailWindow::windowViewerDestroyed (QObject*) {
+    disconnect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
+
+	delete viewerWindow;
+	viewerWindow = 0;
+}
+
 void DetailWindow::passGen (QWidget * _wid) {
 	QPushButton * b = (QPushButton *)_wid;
 
@@ -1425,39 +1448,11 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 	}
 }
 
-//void DetailWindow::windowViewerDestroyed (QObject*) {
-//
-//}
-
-//void DetailWindow::seeOtherPicture() {
-//	if (viewerWindow.isNull() && currentImage != NULL) {
-//		viewerWindow = new ImageViewer(new QImage (*currentImage), this);
-//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
-//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
-//        viewerWindow->show();
-//	}
-//}
-//
-//void DetailWindow::seePicture() {
-//	if (viewerWindow.isNull() && currentImage != NULL) {
-//		viewerWindow = new ImageViewer(new QImage (*currentImage), this);
-//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
-//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
-//        viewerWindow->show();
-//	}
-//}
-//
-//void DetailWindow::seeBackPicture() {
-//	if (viewerWindow.isNull() && currentImageBack != NULL) {
-//		viewerWindow = new ImageViewer(new QImage (*currentImageBack), this);
-//		viewerWindow->setAttribute(Qt::WA_DeleteOnClose);
-//        connect(viewerWindow, SIGNAL(destroyed(QObject*)), this, SLOT(windowViewerDestroyed(QObject*)));
-//        viewerWindow->show();
-//	}
-//}
-
 void DetailWindow::showN () {
 	show ();
+	if (!viewerWindow.isNull()) {
+		viewerWindow->show();
+	}
 	if (!createFieldDlg.isNull()) {
 		createFieldDlg->show();
 	}
@@ -1472,5 +1467,8 @@ void DetailWindow::hideN () {
 	if (!createFieldDlg.isNull()) {
 		createFieldDlg->hide();
 	}
+	if (!viewerWindow.isNull()) {
+		viewerWindow->hide();
+	}
 	hide ();
 }
