@@ -127,6 +127,14 @@ signals:
 	void editTarget(Target * source);
 	void newLikeTarget(Target * source);
 	void duplicateTarget(Target * source);
+
+private slots:
+    void windowViewerDestroyed(QObject* obj);
+    void seePicture (QImage *);
+
+private:
+    QPointer<ImageViewer> viewerWindow;
+
 public:
 	//bool fieldsChanged;
 
