@@ -81,7 +81,7 @@ class ListOfCards::MyDelegate : public QStyledItemDelegate  {
 	QSize sizeHint ( const QStyleOptionViewItem & option, const QModelIndex & index ) const {
 		QVariant val = index.data(Qt::DecorationRole);
 		if (val.isNull()) {
-			return QSize(200, 70);
+			return QSize(800, 70);
 		}
 		else {
 			return QSize(200, SMALL_HEIGH+10);
@@ -123,14 +123,13 @@ void ListOfCards::showList(bool interactive) {
 	//qDebug () << "going to showList";
 
 	setProperty("FingerScrollable", false);
-	centralWidget = this;
 
 	if (interactive) {
 		setContextMenuPolicy(Qt::DefaultContextMenu);
 	} else {
 		setContextMenuPolicy(Qt::NoContextMenu);
 	}
-	//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
+	//	this->setContextMenuPolicy(Qt::DefaultContextMenu);
 
 	vboxlayout = new QVBoxLayout;
 	vboxlayout->setSpacing(0);
@@ -152,10 +151,10 @@ void ListOfCards::showList(bool interactive) {
 	}
 
 	fnListWidget = new QListWidget(this);
-	this->originalDelegate = new MyDelegate(*this, fnListWidget);// TODO fnListWidget->itemDelegate();
-	this->newDelegate = new MyDelegate(*this, fnListWidget);
+//	this->originalDelegate = new MyDelegate(*this, this);// TODO fnListWidget->itemDelegate();
+//	this->newDelegate = new MyDelegate(*this, this);
 
-	//fnListWidget->setItemDelegate(new MyDelegate(fnListWidget));
+	fnListWidget->setItemDelegate(new MyDelegate(*this, this));
 
 	fnListWidget->setSortingEnabled(false);
 	fnListWidget->setFocusPolicy(Qt::NoFocus);
@@ -175,16 +174,13 @@ void ListOfCards::showList(bool interactive) {
 		inputWidget->setContentsMargins(2, 2, 2, 0);
 		vboxlayout->addLayout(inputWidget);
 
-		cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "",
-				this);
-		searchField = new QLineEdit();
-		hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "",
-				this);
+		cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "", this);
+		searchField = new QLineEdit(this);
+		hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
 
 		inputWidget->addWidget(cancelSearch);
 		searchField->setText(currentFilter);
-		searchField->setInputMethodHints(Qt::ImhNoAutoUppercase
-				| Qt::ImhNoPredictiveText);
+		searchField->setInputMethodHints(Qt::ImhNoAutoUppercase	| Qt::ImhNoPredictiveText);
 		inputWidget->addWidget(searchField);
 		inputWidget->addWidget(hideSearch);
 
@@ -208,11 +204,11 @@ void ListOfCards::showList(bool interactive) {
 //	QWidget * window->setContentsMargins(0, 0, 0, 0);
 //	QVBoxLayout * ll = new QVBoxLayout (window);
 //	ll->setContentsMargins(0, 0, 0, 0);
-//	ll->addWidget(centralWidget);
+//	ll->addWidget(this);
 
 	////qDebug () << "setFocus()";
-	centralWidget->setFocusPolicy(Qt::StrongFocus);
-	centralWidget->setFocus();
+	this->setFocusPolicy(Qt::StrongFocus);
+	this->setFocus();
 
 	//fnListWidget->setFocus ();
 
@@ -410,7 +406,7 @@ bool sortStringDES(const QString f, const QString g) {
 }
 
 void ListOfCards::showGroups(bool reset) {
-	qDebug () << "show Groups " << reset;
+	qDebug () << "ListOfCards show Groups " << reset;
 
 	if(!threadLoad.isNull()) {
 		disconnect(threadLoad, SIGNAL(loadImageFor(int)), this, SLOT(loadImageFor(int)));
@@ -425,7 +421,7 @@ void ListOfCards::showGroups(bool reset) {
 		threadLoad = 0;
 	}
 
-	fnListWidget->setItemDelegate(originalDelegate);
+	//fnListWidget->setItemDelegate(originalDelegate);
 
 	int current = fnListWidget->currentRow();
 
@@ -490,7 +486,7 @@ void ListOfCards::showInfo(int isShowGroups, bool reset) {
 
 void ListOfCards::loadImageFor(int index) {
 	if (index >= 0 && index < list.size()) {
-		qDebug () << "loading image for " << index;
+		//qDebug () << "loading image for " << index;
 
 		//QCoreApplication::sendPostedEvents ();
 
@@ -507,7 +503,7 @@ void ListOfCards::showTargets(bool reset, const QString * filter) {
 #ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
-	qDebug () << "show Targets " << reset;
+	qDebug () << "ListOfCards show Targets " << reset;
 
 	if(!threadLoad.isNull()) {
 		disconnect(threadLoad, SIGNAL(loadImageFor(int)), this, SLOT(loadImageFor(int)));
@@ -522,7 +518,7 @@ void ListOfCards::showTargets(bool reset, const QString * filter) {
 		threadLoad = 0;
 	}
 
-	fnListWidget->setItemDelegate(newDelegate);
+	//fnListWidget->setItemDelegate(newDelegate);
 
 	int current = fnListWidget->currentRow();
 
