@@ -61,17 +61,19 @@ void QLabelZ::paintEvent(QPaintEvent* event)
 void LoginDialog::focus () {
 	label->setFocus ();
 }
-LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)paTarget)
+
+LoginDialog::LoginDialog(bool firstTime, QWidget *paTarget): QWidget(paTarget)
 {
 	setContextMenuPolicy(Qt::NoContextMenu);
 
+	qDebug () << "asking password " << firstTime;
 
 	isFirstTime = firstTime;
 	NTimes = 0;
 
 	QHBoxLayout * layout = new QHBoxLayout(this);
 	componentLayout = new QGridLayout ();
-	this->parent = paTarget;
+	//this->parent = paTarget;
 
 	layout->setSpacing(0);
 	layout->setMargin(20);
@@ -156,7 +158,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	aboutButton->setIconSize(QSize(48, 48));
 	QObject::connect(aboutButton, SIGNAL(clicked()), this, SLOT(about()));
 	dlgBtnBox->addButton(aboutButton, QDialogButtonBox::ActionRole);
-
+#ifdef OPEN_SOURCE_VERSION
 	QPushButton * donateButton = new QPushButton(tr("Donate"), this);
 	donateButton->setFixedHeight(70);
 	donateButton->setContextMenuPolicy(Qt::NoContextMenu);
@@ -164,7 +166,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	donateButton->setIconSize(QSize(48, 48));
 	QObject::connect(donateButton, SIGNAL(clicked()), this, SLOT(donate()));
 	dlgBtnBox->addButton(donateButton, QDialogButtonBox::ActionRole);
-
+#endif
 	QPushButton * exitButton = new QPushButton(tr("Exit"), this);
 	exitButton->setFixedHeight(70);
 	exitButton->setContextMenuPolicy(Qt::NoContextMenu);
@@ -228,11 +230,18 @@ LoginDialog::~LoginDialog()
 void LoginDialog::about()
 {
 	this->setStyleSheet("QMessageBox QLabel :link { color: #FF0000; }");
-    QMessageBox::about(this, tr("About Wallet"), tr("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
+#ifdef OPEN_SOURCE_VERSION
+	QMessageBox::about(this, tr("About Wallet"), tr("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
 			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
 			"<p>Icons by http://pixelmixer.ru/</p>"\
 			"<p>if you think that qtWallet is useful for you, please</p>"\
 			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>").arg(VERSION));
+#else
+	QMessageBox::about(this, tr("About Wallet"), tr("<qt><br><br><p><i><b>Wallet</b></i>, v.%1</p>"\
+			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
+			"<p>Icons by http://pixelmixer.ru/</p>"\
+			"</qt>").arg(VERSION));
+#endif
 }
 void LoginDialog::donate() {
 	QDesktopServices::openUrl( QUrl::fromEncoded("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted" ) );
@@ -302,12 +311,16 @@ void LoginDialog::acceptS() {
 		}
 	}
 
-	if (parent->finalPassword (current)) {
+	qDebug () << "Try to validate password";
 
-	}
-	else {
-		clearS ();
-	}
+	emit finalWithPassword (current);
+
+//	if (parent->finalPassword (current)) {
+//
+//	}
+//	else {
+//		clearS ();
+//	}
 }
 
 void LoginDialog::select(const QString& a) {
