@@ -57,6 +57,13 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) :
 	QMainWindow(parent) {
 	setWindowTitle("Wallet");
 
+	centerlayout = new QVBoxLayout;
+	centerwidget = new QWidget;
+	centerwidget->setLayout(centerlayout);
+	setCentralWidget(centerwidget);
+
+	centerlayout->setContentsMargins(0, 0, 0, 0);
+
 	isFirst = false;
 	types = _parent->types;
 	//fieldsByType = _parent->fieldsByType;
@@ -85,6 +92,13 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) :
 eWallet::eWallet(QWidget *parent) :
 	QMainWindow(parent) {
 	setWindowTitle("Wallet");
+
+	centerlayout = new QVBoxLayout;
+	centerwidget = new QWidget;
+	centerwidget->setLayout(centerlayout);
+	setCentralWidget(centerwidget);
+	centerlayout->setContentsMargins(0, 0, 0, 0);
+
 	isShowGroups = 0;
 	isFirst = true;
 	centralWidget = NULL;
@@ -204,27 +218,31 @@ void eWallet::showList(bool interactive) {
 		createMenu();
 	}
 
-	if (isShowGroups == 2) {
-		centralWidget = new ListOfCards (isFirst, currentGroup, this);
-	}
-	else {
-		centralWidget = new ListOfCards (isFirst, this);
-	}
+	if (centralWidget.isNull()) {
+		if (isShowGroups == 2) {
+			centralWidget = new ListOfCards (isFirst, currentGroup, this);
+		}
+		else {
+			centralWidget = new ListOfCards (isFirst, this);
+		}
 
-	if (interactive) {
-		QObject::connect(centralWidget, SIGNAL(selectTarget(Target *)), this, SLOT(viewTarget(Target *)));
-		QObject::connect(centralWidget, SIGNAL(selectGroup(QString *)), this, SLOT(viewGroup(QString *)));
-		QObject::connect(centralWidget, SIGNAL(renameGroup(QString)), this, SLOT(renameGroup(QString)));
-		QObject::connect(centralWidget, SIGNAL(deleteGroup(QString)), this, SLOT(deleteGroup(QString)));
-		QObject::connect(centralWidget, SIGNAL(viewTarget(Target *)), this, SLOT(viewTarget(Target *)));
-		QObject::connect(centralWidget, SIGNAL(editTarget(Target *)), this, SLOT(editTarget(Target *)));
-		QObject::connect(centralWidget, SIGNAL(newLikeTarget(Target *)), this, SLOT(newLikeTarget(Target *)));
-		QObject::connect(centralWidget, SIGNAL(duplicateTarget(Target *)), this, SLOT(duplicateTarget(Target *)));
-		QObject::connect(centralWidget, SIGNAL(deleteTarget(Target *)), this, SLOT(deleteTarget(Target *)));
+		if (interactive) {
+			QObject::connect(centralWidget, SIGNAL(selectTarget(Target *)), this, SLOT(viewTarget(Target *)));
+			QObject::connect(centralWidget, SIGNAL(selectGroup(QString *)), this, SLOT(viewGroup(QString *)));
+			QObject::connect(centralWidget, SIGNAL(renameGroup(QString)), this, SLOT(renameGroup(QString)));
+			QObject::connect(centralWidget, SIGNAL(deleteGroup(QString)), this, SLOT(deleteGroup(QString)));
+			QObject::connect(centralWidget, SIGNAL(viewTarget(Target *)), this, SLOT(viewTarget(Target *)));
+			QObject::connect(centralWidget, SIGNAL(editTarget(Target *)), this, SLOT(editTarget(Target *)));
+			QObject::connect(centralWidget, SIGNAL(newLikeTarget(Target *)), this, SLOT(newLikeTarget(Target *)));
+			QObject::connect(centralWidget, SIGNAL(duplicateTarget(Target *)), this, SLOT(duplicateTarget(Target *)));
+			QObject::connect(centralWidget, SIGNAL(deleteTarget(Target *)), this, SLOT(deleteTarget(Target *)));
+		}
+
+		//setCentralWidget(centralWidget);
+		centerlayout->addWidget(centralWidget);
 	}
-
-	setCentralWidget(centralWidget);
-
+	if (!loginDialogDlg.isNull()) loginDialogDlg->hide();
+	centralWidget->show ();
 	centralWidget->setFocus();
 }
 
@@ -283,6 +301,48 @@ void eWallet::deleteDB() {
 	messageBox = 0;
 }
 
+
+void eWallet::finalUnlock(const QString pass) {
+	bool res = ::dbManager->validatePassword(pass);
+	if (res) {
+		QObject::disconnect(loginDialogDlg, SIGNAL(finalWithPassword(QString)), this,
+			SLOT(finalUnlock(QString)));
+
+		qDebug() << "valid password " << res;
+
+		showN();
+
+		showList(true);
+		//showInfo(false);
+	} else {
+		if (++times > 3) {
+			exit(3);
+		}
+		else {
+#ifdef Q_WS_MAEMO_5
+			show_banner (this, tr("Wrong password"));
+#endif
+#ifndef Q_WS_MAEMO_5
+			if (messageBox.isNull()) {
+				messageBox = new QMessageBox(this);
+				messageBox->information(this, "Wallet",
+						tr("Wrong password"), QMessageBox::Ok);
+			}
+			delete messageBox;
+			messageBox = 0;
+#endif
+
+			if (times == 2) {
+#ifndef OPEN_SOURCE_VERSION
+				AntiTheftManager * manager = new AntiTheftManager (this);
+				manager->notifyFailure ();
+#endif
+			}
+			loginDialogDlg->clearS();
+		}
+	}
+}
+
 bool eWallet::openDataBase(const QString & pas) {
 	tempPass = pas;
 
@@ -313,7 +373,10 @@ bool eWallet::openDataBase(const QString & pas) {
 					manager->notifyFailure ();
 #endif
 				}
+
 			}
+
+			loginDialogDlg->clearS();
 		}
 	}
 	else {
@@ -657,7 +720,7 @@ void eWallet::createMenu() {
 #endif
 		menuBar()->addAction(tr("Options"), this, SLOT(options()));
 #ifndef OPEN_SOURCE_VERSION
-		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
+//		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
 #endif
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
@@ -681,7 +744,7 @@ void eWallet::createMenu() {
 #endif
 		menuBar()->addAction(tr("Options"), this, SLOT(options()));
 #ifndef OPEN_SOURCE_VERSION
-		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
+//		menuBar()->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
 #endif
 		menuBar()->addAction(tr("About"), this, SLOT(about()));
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
@@ -714,7 +777,7 @@ void eWallet::createMenu() {
 #endif
 		m->addAction(tr("Options"), this, SLOT(options()));
 #ifndef OPEN_SOURCE_VERSION
-		m->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
+//		m->addAction(tr("Anti-Theft options"), this, SLOT(optionsAntiTheft()));
 		m->addAction(tr("Templates"), this, SLOT(editTemplates()));
 #endif
 		m->addSeparator();
@@ -1818,10 +1881,15 @@ void eWallet::askPassword() {
 
 	if (loginDialogDlg.isNull()) {
 		loginDialogDlg = new LoginDialog(firstTime, this);
-		QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
-				this, SLOT(finalPassword(QString)));
-		setCentralWidget(loginDialogDlg);
+
+		centerlayout->addWidget(loginDialogDlg);
 	}
+
+	QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
+			this, SLOT(finalPassword(QString)));
+
+	if (!centralWidget.isNull()) centralWidget->hide();
+	loginDialogDlg->show ();
 	loginDialogDlg->focus();
 }
 
@@ -1829,31 +1897,37 @@ void eWallet::hideN() {
 	if (!detailWindowEdit.isNull()) {
 		qDebug() << "hide edit";
 		detailWindowEdit->hideN();
+		detailWindowEdit->hide();
 	}
 	if (!detailWindow.isNull()) {
 		qDebug() << "hide detail";
 		detailWindow->hideN();
+		detailWindow->hide();
 	}
 	if (!extraWindow.isNull()) {
 		qDebug() << "hide extra";
 		extraWindow->hideN();
+		extraWindow->hide();
 	}
-	hide();
+	//if (!isFirst) hide();
 }
 void eWallet::showN() {
 	if (!extraWindow.isNull()) {
-		qDebug() << "hide extra";
+		qDebug() << "show extra";
+		extraWindow->show();
 		extraWindow->showN();
 	}
 	if (!detailWindow.isNull()) {
-		qDebug() << "hide detail";
+		qDebug() << "show detail";
+		detailWindow->show();
 		detailWindow->showN();
 	}
 	if (!detailWindowEdit.isNull()) {
-		qDebug() << "hide edit";
+		qDebug() << "show edit";
+		detailWindowEdit->show();
 		detailWindowEdit->showN();
 	}
-	show();
+	//if (!isFirst) show();
 }
 
 void eWallet::askAgainPassword() {
@@ -1872,15 +1946,19 @@ void eWallet::askAgainPassword() {
 	show_banner (this, tr("Please, enter the password to unlock your wallet"));
 #endif
 
-	//if (loginDialogDlg.isNull()) {
-	loginDialogDlg = new LoginDialog(false, this);
-	QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)), this,
-			SLOT(finalUnlock(QString)));
-	setCentralWidget(loginDialogDlg);
-	//}
-	loginDialogDlg->focus();
+	if (loginDialogDlg.isNull()) {
+		loginDialogDlg = new LoginDialog(false, this);
 
-	show();
+		centerlayout->addWidget(loginDialogDlg);
+	}
+
+	QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)), this,
+		SLOT(finalUnlock(QString)));
+
+	if (!centralWidget.isNull()) centralWidget->hide();
+	loginDialogDlg->clearS();
+	loginDialogDlg->show ();
+	loginDialogDlg->focus();
 }
 
 void eWallet::options() {
@@ -1920,35 +1998,27 @@ void eWallet::about() {
 void eWallet::finalPassword(const QString pass) {
 	bool res = openDataBase(pass);
 	if (res) {
+		QObject::disconnect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
+				this, SLOT(finalPassword(QString)));
+
 		loadTypesAndFields();
 #ifdef Q_WS_MAEMO_5
 		QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
 		conn.connect("","", QString("com.nokia.mce.signal"/*MCE_SIGNAL_IF*/), QString("display_status_ind"/*MCE_DISPLAY_SIG*/) , this, SLOT(listenInactivity(QString)));
 		//bool success = conn.connect("","", QString(MCE_SIGNAL_IF), QString(MCE_DISPLAY_SIG) , this, SLOT(listenInactivity(QString)));
 #endif
-
+//		loginDialogDlg = 0;
 		showInfo (false);
 	}
 }
 
 void eWallet::finalChangePassword(const QString pass) {
+	QObject::disconnect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
+			this, SLOT(finalChangePassword(QString)));
+
 	reallyChangePassword(pass);
 }
 
-void eWallet::finalUnlock(const QString pass) {
-	bool res = ::dbManager->validatePassword(pass);
-	if (res) {
-		qDebug() << "valid password " << res;
-
-		showN();
-
-		showList(true);
-		showInfo(false);
-	} else {
-		qDebug() << "invalid password";
-	}
-}
-
 void eWallet::preProcessImage(QImage * image) {
 	if (image == NULL)
 		return;
@@ -1998,15 +2068,17 @@ void eWallet::changePassword() {
 	if (loginDialogDlg.isNull()) {
 		loginDialogDlg = new LoginDialog(true, this);
 
-		QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
-				this, SLOT(finalChangePassword(QString)));
-
-		setCentralWidget(loginDialogDlg);
-		setFocus();
-		loginDialogDlg->setFocus();
-		focusNextChild();
+		centerlayout->addWidget(loginDialogDlg);
 	}
 
+	QObject::connect(loginDialogDlg, SIGNAL(finalWithPassword(QString)),
+			this, SLOT(finalChangePassword(QString)));
+
+	if (!centralWidget.isNull()) centralWidget->hide ();
+	loginDialogDlg->show();
+	setFocus();
+	loginDialogDlg->setFocus();
+	focusNextChild();
 }
 
 class MyThread: public QThread {
@@ -2023,7 +2095,7 @@ public:
 };
 
 void eWallet::reallyChangePassword(const QString & newPassword) {
-	showList(false);
+//	loginDialogDlg = 0;
 
 	//	QMessageBox * messageBox = new QMessageBox (this);
 	//	messageBox->information(this, "Wallet", tr("Changing password, please wait until application quits"), QMessageBox::Ok);
@@ -2086,6 +2158,8 @@ void eWallet::reallyChangePassword(const QString & newPassword) {
 	::dbManager->close();
 	openDataBase(newPassword);
 
+	showList(false);
+
 	//	::dbManager->lock ();
 	//	askPassword ();
 }
