@@ -177,7 +177,11 @@ private:
 	QPointer<DetailWindow> detailWindow;
 	QPointer<DetailWindow> detailWindowEdit;
 	QPointer<eWallet> extraWindow;
-	ListOfCards * centralWidget;
+	QPointer<ListOfCards> centralWidget;
+
+	QWidget * centerwidget;
+	QVBoxLayout * centerlayout;
+
 	QPointer <QMessageBox> messageBox;
 	bool opendb;
 	bool initdb;
