@@ -47,12 +47,14 @@ int main(int argc, char *argv[])
     //myappTranslator.load(QString (":/resources/locale/qtwallet_") + lang);
     app.installTranslator(&myappTranslator);
 
-	eWallet * w = new eWallet();
-	w->show();
+	eWallet w;
+	w.show();
 	int ret = app.exec();
 
-	delete ::dbManager;
+	qDebug () << "app end " << ret;
 
-	delete w;
+	//delete ::dbManager;
+
+	//delete w;
 	return ret;
 }
