@@ -1,5 +1,6 @@
 #include "utils.h"
 
+#ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
 
 
@@ -37,3 +38,4 @@ void show_banner  (QWidget * w, const QString & t)
 //
 //    //gtk_object_destroy (GTK_OBJECT (note));
 }
+#endif
